O           
[![PyPI version](https://badge.fury.io/py/generic-proto-plus-stubs.svg)](https://badge.fury.io/py/generic-proto-plus-stubs)

This package provides type stubs for the [proto-plus](https://pypi.org/project/proto-plus/) package with 
some use of generics. 

**This is in no way affiliated with Google.**

**This is basically just a fork of [henribru/proto-plus-stubs](https://github.com/henribru/proto-plus-stubs)
with some manually added code to make use of pythons generics**

The stubs were created automatically by [stubgen](https://mypy.readthedocs.io/en/stable/stubgen.html).
## Installation
```shell script
$ pip install generic-proto-stubs
```
